@@ -1,4 +1,5 @@
 #!/usr/bin/python
+# -*- coding: iso-8859-15 -*-
 
 ### OPEN SOURCE LICENSE - GNU AFFERO PUBLIC LICENSE Version 3.0 #######
 #
@@ -227,10 +228,10 @@ upload(url,pem_file_path,bearer)
 time.sleep( 1 )
 
 data = {'cmd': [['cmd','mv /tmp/'+args.pem_file+
-                 ' '+home+'/FullAutoAPI'],
+                 ' '+os.getcwd()],
                 ['cmd','mv /tmp/'+credentials_file+
-                 ' '+home+'/FullAutoAPI'],
-                ['cwd',home+'/FullAutoAPI'],
+                 ' '+os.getcwd()],
+                ['cwd',os.getcwd()],
                 ['cmd','chmod 400 '+args.pem_file],
                 ['cmd',new_sg],
                 ['cmd',ingress]]}
@@ -284,7 +285,7 @@ while loop == 1: # This creates an infinite loop
       break
 print '==================='
 print docker_ip
-data = {'cmd': [['connect_secure',{'ip':docker_ip,'login':'ec2-user','identityfile':home+'/FullAutoAPI/'+args.pem_file,'noretry':'1'}]]}
+data = {'cmd': [['connect_secure',{'ip':docker_ip,'login':'ec2-user','identityfile':os.getcwd()+'/'+args.pem_file,'noretry':'1'}]]}
 time.sleep( 1 )
 docker_server1='';
 print "\nGoing to Attempt to Connect to new Docker Server via ssh . . .\n"
@@ -316,7 +317,7 @@ headerz, content = http.request(url, "POST", body=dumps(data), headers=headers)
 result = json.loads(content)
 result = json.loads(result['result'])
 print result
-data = {'cmd': [['connect_secure',{'ip':docker_ip,'login':'ec2-user','identityfile':home+'/FullAutoAPI/'+args.pem_file,'noretry':'1'}]]}
+data = {'cmd': [['connect_secure',{'ip':docker_ip,'login':'ec2-user','identityfile':os.getcwd()+'/'+args.pem_file,'noretry':'1'}]]}
 time.sleep( 1 )
 docker_server1='';
 while loop == 1: # This creates an infinite loop
