@@ -139,7 +139,7 @@ sub get_aws_security_id {
          $_[0];
    my ($hash,$output,$error)=('','','');
    ($hash,$output,$error)=run_aws_cmd($g);
-   Net::FullAuto::FA_Core::handle_error($error) if $error;
+   &exit_on_error($error) if $error;
    return $hash->{SecurityGroups}->[0]->{GroupId};
 
 }
@@ -149,17 +149,9 @@ sub get_fullauto_instance {
    my ($hash,$json,$output,$error)=('','','','');
    ($hash,$output,$error)=
        run_aws_cmd("aws ec2 describe-instances");
-   if ($error) {
-      eval {
-         local $SIG{ALRM} = sub { die "alarm\n" }; # \n required
-         alarm 120;
-         $error=~s/^\s*//;
-         $error=~s/: /:\n   /;
-         print "\n   $error\n   Press Any Key to EXIT ... ";
-         <STDIN>;
-      };alarm(0);
-      Net::FullAuto::FA_Core::cleanup();
-   }
+   $error=~s/^\s*//;
+   $error=~s/: /:\n   /;
+   &exit_on_error($error) if $error;
    my $instance='';
    my $ipaddress=Socket::inet_ntoa((gethostbyname(
                  $Net::FullAuto::FA_Core::local_hostname))[4]);
@@ -190,9 +182,9 @@ sub wait_for_instance {
          unless ($flag) {
             $flag=1;sleep 5;next;
          }
-         Net::FullAuto::FA_Core::handle_error($output);
+         &exit_on_error($output);
       } elsif ($error) {
-         Net::FullAuto::FA_Core::handle_error($error);
+         &exit_on_error($error);
       }
       last;
    }
@@ -210,11 +202,9 @@ sub launch_instance {
    my ($hash,$output,$error)=('','','');
    ($hash,$output,$error)=run_aws_cmd($launch_cmd);
    if ($error) {
-      print "\n\n   $error\n\n";sleep 3600; 
-      Net::FullAuto::FA_Core::handle_error($error);
+      &exit_on_error($error);
    } elsif ($output=~/An error occurred/) {
-      print "\n\n   $output\n\n";sleep 3600;
-      Net::FullAuto::FA_Core::handle_error($output);
+      &exit_on_error($output);
    }
    my $inst=$hash->{Instances}->[0];
    my $server_launch=<<'END';
@@ -749,7 +739,7 @@ my $get_ec2_api=sub {
    my ($hash,$output,$error)=('','','');
    ($hash,$output,$error)=Net::FullAuto::Cloud::fa_amazon::run_aws_cmd(
       "aws iam list-access-keys");
-   Net::FullAuto::FA_Core::handle_error($error) if $error;
+   &exit_on_error($error) if $error;
    $Net::FullAuto::Cloud::fa_amazon::configure_aws1->()
       if (-1<index $output,'configure credentials') ||
       (-1<index $output,'Partial credentials found');
@@ -1085,7 +1075,7 @@ sub new_user_amazon {
    my ($hash,$output,$error)=('','','');
    ($hash,$output,$error)=Net::FullAuto::Cloud::fa_amazon::run_aws_cmd(
       "aws iam list-access-keys");
-   Net::FullAuto::FA_Core::handle_error($error) if $error;
+   &exit_on_error($error) if $error;
    $need_to_configure_aws=1 if (-1<index $output,'configure credentials') ||
       (-1<index $output,'Partial credentials found');
    my $credentials_csv_path='.';
@@ -1268,4 +1258,19 @@ END
 
 }
 
+sub exit_on_error {
+
+   eval {
+      local $SIG{ALRM} = sub { die "alarm\n" }; # \n required
+      alarm 3600;
+      print "\n\n   FATAL ERROR!:\n   ";
+      print $_[0];
+      print "   \n   Press Any Key to EXIT ... ";
+      <STDIN>;
+   };alarm(0);
+   print "\n";
+   &Net::FullAuto::FA_Core::cleanup;
+
+}
+
 1
